==> amaya-src-2.4.tgz: Amaya/thotlib/include/unicodeconsts.h <==
#ifndef _UCS2_CONST
#define _UCS2_CONST

#if defined(_I18N_) || defined(__JIS__)

/*           Special characters */
#   define _NEWLINE_          L"\n"
#   define _TABULATION_       L"\t"

#   define _LEXCST_               L"LEX"
#   define _LibdialogueCST_       L"libdialogue"
#   define _MenuAttributeCST_     L"MenuAttribute"
#   define _MenuHelpCST_          L"MenuHelp"
#   define _MenuSelectionCST_     L"MenuSelection"
#   define _NumAttrClassCST_      L"NumAttrClass"
#   define _ReadOnlyColorCST_     L"ReadOnlyColor"
#   define _SaveFileAsCST_        L"Save File as"
#   define _ScrollbarCST_         L"scrollbar"
#   define _SheetClassCST_        L"SheetClass" 
#   define _SpecialCharsCST_      L"@#$&+~" 
#   define _ThotColorPaletteCST_  L"ThotColorPalette"
#   define _WNDIALOGBOXCST_       L"WNDIALOGBOX"

#   define _THOTElement_          L"thot"
#   define _XMLElement_           L"xml"
#   define _XMLNameSpace_         L"xmlns"

#   define _AmayaFatalErrorMSG_            L"Amaya: fatal error"
#   define _AttributeElementMismatchMSG_   L"attribute element mismatch"
#   define _BufferTooSmallMSG_             L"buffer too small"
#   define _CannotHolophrastARootMSG_      L"cannot holophrast a root"
#   define _CannotHolophrastThatTypeMSG_   L"cannot holophrast that type"
#   define _CannotLoadPschemaMSG_          L"cannot load pschema"
#   define _CannotReadStructureSchemaMSG_  L"cannot read structure schema"
#   define _CannotOpenViewMSG_             L"cannot open view"
#   define _CannotOpenPivotFileMSG_        L"cannot open pivot file"
#   define _CannotSetLinkMSG_              L"cannot set link"
#   define _DuplicateAttributeMSG_         L"duplicate attribute"
#   define _DuplicatePresentationRuleMSG_  L"duplicate presentation rule"
#   define _EmptyDocumentMSG_              L"empty document"
#   define _ElementAlreadyInsertedMSG_     L"element already inserted"
#   define _ElementDoesNotMatchDTDMSG_     L"element does not match DTD"
#   define _ElementHasNoBoxMSG_            L"element has no box"
#   define _FeatureNotImplementedMSG_      L"feature not implemented"
#   define _IncorrectTreeMSG_              L"incorrect tree"
#   define _InvalidAssociatedRootMSG_      L"invalid associated root"
#   define _InvalidAttributeTypeMSG_       L"invalid attribute type"
#   define _InvalidAttributeValueMSG_      L"invalid attribute value"
#   define _InvalidButtonNdxMSG_           L"Invalid Button Index"
#   define _InvalidDocumentNameMSG_        L"invalid document name" 
#   define _InvalidDocumentParameterMSG_   L"invalid document parameter"
#   define _InvalidElementTypeMSG_         L"invalid element type"
#   define _InvalidParameterMSG_           L"invalid parameter"
#   define _LanguageNotFoundMSG_           L"language not found"
#   define _LanguageTableIsFullMSG_        L"language table is full"
#   define _MainWindowNotOpenMSG_          L"main window not open"
#   define _MandatoryAttributeMSG_         L"mandatory attribute"
#   define _NoPresentationSchemaMSG_       L"no presentation schema"
#   define _NoSelectionInDocumentMSG_      L"no selection in document"
#   define _ReadOnlyDocumentMSG_           L"read only document"
#   define _SpellCheckingMSG_              L"Spell checking"
#   define _StringTooLongMSG_              L"string too long"
#   define _ThereAreOpenViewsMSG_          L"there are open views"
#   define _TooManyDocumentsMSG_           L"too many documents" 

#   define BAK_EXT2                        L"BAK"
#   define EXE_EXT                         L".exe"
#   define EXE_EXT2                        L"EXE"
#   define EXT_EXT2                        L"EXT"
#   define KB_EXT                          L".kb"
#   define html_EXT                        L".html"
#   define html_EXT2                       L"html"
#   define Keyboard_EXT                    L".keyboard"
#   define OLD_EXT2                        L"OLD"
#   define PIV_EXT2                        L"PIV"
#   define PRS_EXT                         L".PRS"
#   define PRS_EXT2                        L"PRS"
#   define Ps_EXT2                         L"ps"
#   define REF_EXT2                        L"REF"
#   define SAV_EXT2                        L"SAV"
#   define STR_EXT                         L".STR"
#   define STR_EXT2                        L"STR"
#   define Tmp_EXT2                        L"Tmp"
#   define TRA_EXT                         L".TRA"
#   define TRA_EXT2                        L"TRA"
#   define X_EXT                           L".X"
#   define XML_EXT                         L".xml"
#   define XML_EXT2                        L"XML"

#   define _CsLANG_                        L"cs"
#   define _FiLANG_                        L"fi"
#   define _ElLANG_                        L"el"
#   define _EsLANG_                        L"es"
#   define _ItLANG_                        L"it"
#   define _NlLANG_                        L"nl"
#   define _PlLANG_                        L"pl"
#   define _PtLANG_                        L"pt"
#   define _SvLANG_                        L"sv"
#   define _TrLANG_                        L"tr"
#   define _EnUSLANG_                      L"en-US"


#   define _BackgroundColor_EVAR_          L"BackgroundColor"
#   define _CACHEDIR_EVAR_                 L"CACHE_DIR"
#   define _CACHEDISCONNECTEDMODE_EVAR_    L"CACHE_DISCONNECTED_MODE"
#   define _CACHEEXPIREIGNORE_EVAR_        L"CACHE_EXPIRE_IGNORE"
#   define _CACHEPROTECTEDDOCS_EVAR_       L"CACHE_PROTECTED_DOCS"
#   define _CACHESIZE_EVAR_                L"CACHE_SIZE"
#   define _DNSTIMEOUT_EVAR_               L"DNS_TIMEOUT"
#   define _DOUBLECLICKDELAY_EVAR_         L"DOUBLECLICKDELAY"
#   define _ENABLEBGIMAGES_EVAR_           L"ENABLE_BG_IMAGES"
#   define _ENABLECACHE_EVAR_              L"ENABLE_CACHE"
#   define _ENABLEDOUBLECLICK_EVAR_        L"ENABLE_DOUBLECLICK"
#   define _ENABLELOSTUPDATECHECK_EVAR_    L"ENABLE_LOST_UPDATE_CHECK"
#   define _ENABLEMDA_EVAR_                L"ENABLE_MDA"
#   define _ENABLEPIPELINING_EVAR_         L"ENABLE_PIPELINING"
#   define _ForegroundColor_EVAR_          L"ForegroundColor"
#   define _HOME_EVAR_                     L"HOME"
#   define _HTTPPROXY_EVAR_                L"HTTP_PROXY"
#   define _MAXCACHEENTRYSIZE_EVAR_        L"MAX_CACHE_ENTRY_SIZE"
#   define _MAXSOCKET_EVAR_                L"MAX_SOCKET"
#   define _NETEVENTTIMEOUT_EVAR_          L"NET_EVENT_TIMEOUT"
#   define _PROXYDOMAIN_EVAR_              L"PROXYDOMAIN"
#   define _PROXYDOMAINISONLYPROXY_EVAR_   L"PROXYDOMAIN_IS_ONLYPROXY"
#   define _PAPERSIZE_EVAR_                L"PAPERSIZE"
#   define _PATH_EVAR_                     L"PATH"
#   define _PERSISTCXTIMEOUT_EVAR_         L"PERSIST_CX_TIMEOUT"
#   define _PWD_EVAR_                      L"PWD"
#   define _TOOLTIPDELAY_EVAR_             L"TOOLTIPDELAY"


#   define _AltKEY_                        L"Alt"
#   define _BackspaceKEY_                  L"backspace"
#   define _CtrlKEY_                       L"Ctrl"
#   define _DeleteKEY_                     L"delete"
#   define _DownKEY_                       L"down"
#   define _EndKEY_                        L"end"
#   define _EscapeKEY_                     L"escape"
#   define _HomeKEY_                       L"home"
#   define _LeftKEY_                       L"left"
#   define _MetaKEY_                       L"meta"
#   define _RightKEY_                      L"right"
#   define _ReturnKEY_                     L"Return"
#   define _ShiftKEY_                      L"Shift"
#   define _SpaceKEY_                      L"Space"
#   define _UpKEY_                         L"up"

#   define _KBKeyRC_                       L"<Key>"

#   define _RBinaryMODE_                   L"rb"
#   define _WriteMODE_                     L"w" 
#   define _WBinaryMODE_                   L"wb" 
#   define _AppendBinaryMODE_              L"wb+"
#   define _RW_MODE_                       L"rw"
#   define _AppendMODE_                    L"w+"       

#   define _USPaperFormat_                 L"US"
#   define _A4PaperFormat_                 L"A4"
#   define _A3PaperFormat_                 L"A3"

#   define  WIN_DEF_TMPDIR                 L"c:\\temp"

#else  /* !_I18N_ */

/*     Special characters */
#      define _NEWLINE_           "\n"
#      define _TABULATION_        "\t"

#      define _LEXCST_               "LEX"
#      define _LibdialogueCST_       "libdialogue"
#      define _MenuAttributeCST_     "MenuAttribute"
#      define _MenuHelpCST_          "MenuHelp"
#      define _MenuSelectionCST_     "MenuSelection"
#      define _NumAttrClassCST_      "NumAttrClass"
#      define _ReadOnlyColorCST_     "ReadOnlyColor"
#      define _SaveFileAsCST_        "Save File as"
#      define _ScrollbarCST_          "scrollbar"
#      define _SheetClassCST_        "SheetClass" 
#      define _SpecialCharsCST_      "@#$&+~" 
#      define _ThotColorPaletteCST_  "ThotColorPalette"
#      define _WNDIALOGBOXCST_       "WNDIALOGBOX"

#      define _THOTElement_          "thot"
#      define _XMLElement_           "xml"
#      define _XMLNameSpace_         "xmlns"

#      define _AmayaFatalErrorMSG_            "Amaya: fatal error"
#      define _AttributeElementMismatchMSG_   "attribute element mismatch"
#      define _BufferTooSmallMSG_             "buffer too small"
#      define _CannotHolophrastARootMSG_      "cannot holophrast a root"
#      define _CannotHolophrastThatTypeMSG_   "cannot holophrast that type"
#      define _CannotLoadPschemaMSG_          "cannot load pschema"
#      define _CannotReadStructureSchemaMSG_  "cannot read structure schema"
#      define _CannotOpenPivotFileMSG_        "cannot open pivot file"
#      define _CannotOpenViewMSG_             "cannot open view"
#      define _CannotSetLinkMSG_              "cannot set link"
#      define _DuplicateAttributeMSG_         "duplicate attribute"
#      define _DuplicatePresentationRuleMSG_  "duplicate presentation rule"
#      define _EmptyDocumentMSG_              "empty document"
#      define _ElementAlreadyInsertedMSG_     "element already inserted"
#      define _ElementDoesNotMatchDTDMSG_     "element does not match DTD"
#      define _ElementHasNoBoxMSG_            "element has no box"
#      define _FeatureNotImplementedMSG_      "feature not implemented"
#      define _IncorrectTreeMSG_              "incorrect tree"
#      define _InvalidAssociatedRootMSG_      "invalid associated root"
#      define _InvalidAttributeTypeMSG_       "invalid attribute type"
#      define _InvalidAttributeValueMSG_      "invalid attribute value"
#      define _InvalidButtonNdxMSG_           "Invalid Button Index" 
#      define _InvalidDocumentNameMSG_        "invalid document name"
#      define _InvalidDocumentParameterMSG_   "invalid document parameter"
#      define _InvalidElementTypeMSG_         "invalid element type"
#      define _InvalidParameterMSG_           "invalid parameter"
#      define _LanguageNotFoundMSG_           "language not found"
#      define _LanguageTableIsFullMSG_        "language table is full"
#      define _MainWindowNotOpenMSG_          "main window not open"
#      define _MandatoryAttributeMSG_         "mandatory attribute"
#      define _NoPresentationSchemaMSG_       "no presentation schema"
#      define _NoSelectionInDocumentMSG_      "no selection in document"
#      define _ReadOnlyDocumentMSG_           "read only document"
#      define _SpellCheckingMSG_              "Spell checking"
#      define _StringTooLongMSG_              "string too long"
#      define _ThereAreOpenViewsMSG_          "there are open views"
#      define _TooManyDocumentsMSG_           "too many documents" 

#      define BAK_EXT2                        "BAK"
#      define EXE_EXT                         ".exe"
#      define EXE_EXT2                        "EXE"
#      define EXT_EXT2                        "EXT"
#      define html_EXT                        ".html"
#      define html_EXT2                       "html"
#      define KB_EXT                          ".kb"
#      define Keyboard_EXT                    ".keyboard"
#      define OLD_EXT2                        "OLD"
#      define PIV_EXT2                        "PIV"
#      define PRS_EXT                         ".PRS"
#      define PRS_EXT2                        "PRS"
#      define Ps_EXT2                         "ps"
#      define REF_EXT2                        "REF"
#      define SAV_EXT2                        "SAV"
#      define STR_EXT                         ".STR"
#      define STR_EXT2                        "STR"
#      define Tmp_EXT2                        "Tmp"
#      define TRA_EXT                         ".TRA"
#      define TRA_EXT2                        "TRA"
#      define X_EXT                           ".X"
#      define XML_EXT                         ".xml"
#      define XML_EXT2                        "XML"

#      define _BackgroundColor_EVAR_          "BackgroundColor"
#      define _CACHEDIR_EVAR_                 "CACHE_DIR"
#      define _CACHEDISCONNECTEDMODE_EVAR_    "CACHE_DISCONNECTED_MODE"
#      define _CACHEEXPIREIGNORE_EVAR_        "CACHE_EXPIRE_IGNORE"
#      define _CACHEPROTECTEDDOCS_EVAR_       "CACHE_PROTECTED_DOCS"
#      define _CACHESIZE_EVAR_                "CACHE_SIZE"
#      define _DNSTIMEOUT_EVAR_               "DNS_TIMEOUT"
#      define _DOUBLECLICKDELAY_EVAR_         "DOUBLECLICKDELAY"
#      define _ENABLEBGIMAGES_EVAR_           "ENABLE_BG_IMAGES"
#      define _ENABLECACHE_EVAR_              "ENABLE_CACHE"
#      define _ENABLEDOUBLECLICK_EVAR_        "ENABLE_DOUBLECLICK"
#      define _ENABLELOSTUPDATECHECK_EVAR_    "ENABLE_LOST_UPDATE_CHECK"
#      define _ENABLEMDA_EVAR_                "ENABLE_MDA"
#      define _ENABLEPIPELINING_EVAR_         "ENABLE_PIPELINING"
#      define _ForegroundColor_EVAR_          "ForegroundColor"
#      define _HOME_EVAR_                     "HOME"
#      define _HTTPPROXY_EVAR_                "HTTP_PROXY"
#      define _MAXCACHEENTRYSIZE_EVAR_        "MAX_CACHE_ENTRY_SIZE"
#      define _MAXSOCKET_EVAR_                "MAX_SOCKET"
#      define _NETEVENTTIMEOUT_EVAR_          "NET_EVENT_TIMEOUT"
#      define _PROXYDOMAIN_EVAR_              "PROXYDOMAIN"
#      define _PROXYDOMAINISONLYPROXY_EVAR_ "PROXYDOMAIN_IS_ONLYPROXY"
#      define _PAPERSIZE_EVAR_                "PAPERSIZE"
#      define _PATH_EVAR_                     "PATH"
#      define _PERSISTCXTIMEOUT_EVAR_         "PERSIST_CX_TIMEOUT"
#      define _PWD_EVAR_                      "PWD"
#      define _TOOLTIPDELAY_EVAR_             "TOOLTIPDELAY"

#      define _AltKEY_                        "Alt"
#      define _BackspaceKEY_                  "backspace"
#      define _CtrlKEY_                       "Ctrl"
#      define _DeleteKEY_                     "delete"
#      define _DownKEY_                       "down"
#      define _EndKEY_                        "end"
#      define _EscapeKEY_                     "escape"
#      define _HomeKEY_                       "home"
#      define _LeftKEY_                       "left"
#      define _MetaKEY_                       "meta"
#      define _RightKEY_                      "right"
#      define _ReturnKEY_                     "Return"
#      define _ShiftKEY_                      "Shift"
#      define _SpaceKEY_                      "Space"
#      define _UpKEY_                         "up"

#      define _KBKeyRC_                       "<Key>"

#      define _RBinaryMODE_                   "rb"
#      define _RW_MODE_                       "rw"
#      define _WBinaryMODE_                   "wb" 
#      define _AppendBinaryMODE_              "wb+"
#      define _WriteMODE_                     "w" 
#      define _AppendMODE_                    "w+" 

#      define _USPaperFormat_                  "US"
#      define _A4PaperFormat_                  "A4"
#      define _A3PaperFormat_                  "A3"

#      ifdef _WINDOWS
#      define  WIN_DEF_TMPDIR           "c:\\temp"
#      else  /* !_WINDOWS */
#      endif /* ! _WINDOWS */


#endif /* !_I18N_ */

#endif /* _UCS2_CONST */

==> amaya-src-4.0.tgz: Amaya/thotlib/include/unicodeconsts.h <==
#ifndef _UCS2_CONST
#define _UCS2_CONST

#if defined(_I18N_) || defined(__JIS__)

#   define _AmayaFatalErrorMSG_            L"Amaya: fatal error"
#   define _AttributeElementMismatchMSG_   L"attribute element mismatch"
#   define _BufferTooSmallMSG_             L"buffer too small"
#   define _CannotHolophrastARootMSG_      L"cannot holophrast a root"
#   define _CannotHolophrastThatTypeMSG_   L"cannot holophrast that type"
#   define _CannotLoadPschemaMSG_          L"cannot load pschema"
#   define _CannotReadStructureSchemaMSG_  L"cannot read structure schema"
#   define _CannotOpenViewMSG_             L"cannot open view"
#   define _CannotOpenPivotFileMSG_        L"cannot open pivot file"
#   define _CannotSetLinkMSG_              L"cannot set link"
#   define _DuplicateAttributeMSG_         L"duplicate attribute"
#   define _DuplicatePresentationRuleMSG_  L"duplicate presentation rule"
#   define _EmptyDocumentMSG_              L"empty document"
#   define _ElementAlreadyInsertedMSG_     L"element already inserted"
#   define _ElementDoesNotMatchDTDMSG_     L"element does not match DTD"
#   define _ElementHasNoBoxMSG_            L"element has no box"
#   define _FeatureNotImplementedMSG_      L"feature not implemented"
#   define _IncorrectTreeMSG_              L"incorrect tree"
#   define _InvalidAssociatedRootMSG_      L"invalid associated root"
#   define _InvalidAttributeTypeMSG_       L"invalid attribute type"
#   define _InvalidAttributeValueMSG_      L"invalid attribute value"
#   define _InvalidButtonNdxMSG_           L"Invalid Button Index"
#   define _InvalidDocumentNameMSG_        L"invalid document name" 
#   define _InvalidDocumentParameterMSG_   L"invalid document parameter"
#   define _InvalidElementTypeMSG_         L"invalid element type"
#   define _InvalidParameterMSG_           L"invalid parameter"
#   define _LanguageNotFoundMSG_           L"language not found"
#   define _LanguageTableIsFullMSG_        L"language table is full"
#   define _MainWindowNotOpenMSG_          L"main window not open"
#   define _MandatoryAttributeMSG_         L"mandatory attribute"
#   define _NoPresentationSchemaMSG_       L"no presentation schema"
#   define _NoSelectionInDocumentMSG_      L"no selection in document"
#   define _ReadOnlyDocumentMSG_           L"read only document"
#   define _SpellCheckingMSG_              L"Spell checking"
#   define _StringTooLongMSG_              L"string too long"
#   define _ThereAreOpenViewsMSG_          L"there are open views"
#   define _TooManyDocumentsMSG_           L"too many documents" 

#   define BAK_EXT2                        L"BAK"
#   define EXE_EXT                         L".exe"
#   define EXE_EXT2                        L"EXE"
#   define EXT_EXT2                        L"EXT"
#   define KB_EXT                          L".kb"
#   define html_EXT                        L".html"
#   define html_EXT2                       L"html"
#   define Keyboard_EXT                    L".keyboard"
#   define OLD_EXT2                        L"OLD"
#   define PIV_EXT2                        L"PIV"
#   define PRS_EXT                         L".PRS"
#   define PRS_EXT2                        L"PRS"
#   define Ps_EXT2                         L"ps"
#   define REF_EXT2                        L"REF"
#   define SAV_EXT2                        L"SAV"
#   define STR_EXT                         L".STR"
#   define STR_EXT2                        L"STR"
#   define Tmp_EXT2                        L"Tmp"
#   define TRA_EXT                         L".TRA"
#   define TRA_EXT2                        L"TRA"
#   define X_EXT                           L".X"
#   define XML_EXT                         L".xml"
#   define XML_EXT2                        L"XML"

#   define _CsLANG_                        L"cs"
#   define _FiLANG_                        L"fi"
#   define _ElLANG_                        L"el"
#   define _EsLANG_                        L"es"
#   define _ItLANG_                        L"it"
#   define _NlLANG_                        L"nl"
#   define _PlLANG_                        L"pl"
#   define _PtLANG_                        L"pt"
#   define _SvLANG_                        L"sv"
#   define _TrLANG_                        L"tr"
#   define _EnUSLANG_                      L"en-US"

#   define _RBinaryMODE_                   L"rb"
#   define _WriteMODE_                     L"w" 
#   define _WBinaryMODE_                   L"wb" 
#   define _AppendBinaryMODE_              L"wb+"
#   define _RW_MODE_                       L"rw"
#   define _AppendMODE_                    L"w+"       

#   define _USPaperFormat_                 L"US"
#   define _A4PaperFormat_                 L"A4"
#   define _A3PaperFormat_                 L"A3"

/* #   define  WIN_DEF_TMPDIR                 L"c:\\temp" */

#else  /* !_I18N_ */

#      define _AmayaFatalErrorMSG_            "Amaya: fatal error"
#      define _AttributeElementMismatchMSG_   "attribute element mismatch"
#      define _BufferTooSmallMSG_             "buffer too small"
#      define _CannotHolophrastARootMSG_      "cannot holophrast a root"
#      define _CannotHolophrastThatTypeMSG_   "cannot holophrast that type"
#      define _CannotLoadPschemaMSG_          "cannot load pschema"
#      define _CannotReadStructureSchemaMSG_  "cannot read structure schema"
#      define _CannotOpenPivotFileMSG_        "cannot open pivot file"
#      define _CannotOpenViewMSG_             "cannot open view"
#      define _CannotSetLinkMSG_              "cannot set link"
#      define _DuplicateAttributeMSG_         "duplicate attribute"
#      define _DuplicatePresentationRuleMSG_  "duplicate presentation rule"
#      define _EmptyDocumentMSG_              "empty document"
#      define _ElementAlreadyInsertedMSG_     "element already inserted"
#      define _ElementDoesNotMatchDTDMSG_     "element does not match DTD"
#      define _ElementHasNoBoxMSG_            "element has no box"
#      define _FeatureNotImplementedMSG_      "feature not implemented"
#      define _IncorrectTreeMSG_              "incorrect tree"
#      define _InvalidAssociatedRootMSG_      "invalid associated root"
#      define _InvalidAttributeTypeMSG_       "invalid attribute type"
#      define _InvalidAttributeValueMSG_      "invalid attribute value"
#      define _InvalidButtonNdxMSG_           "Invalid Button Index" 
#      define _InvalidDocumentNameMSG_        "invalid document name"
#      define _InvalidDocumentParameterMSG_   "invalid document parameter"
#      define _InvalidElementTypeMSG_         "invalid element type"
#      define _InvalidParameterMSG_           "invalid parameter"
#      define _LanguageNotFoundMSG_           "language not found"
#      define _LanguageTableIsFullMSG_        "language table is full"
#      define _MainWindowNotOpenMSG_          "main window not open"
#      define _MandatoryAttributeMSG_         "mandatory attribute"
#      define _NoPresentationSchemaMSG_       "no presentation schema"
#      define _NoSelectionInDocumentMSG_      "no selection in document"
#      define _ReadOnlyDocumentMSG_           "read only document"
#      define _SpellCheckingMSG_              "Spell checking"
#      define _StringTooLongMSG_              "string too long"
#      define _ThereAreOpenViewsMSG_          "there are open views"
#      define _TooManyDocumentsMSG_           "too many documents" 

#      define BAK_EXT2                        "BAK"
#      define EXE_EXT                         ".exe"
#      define EXE_EXT2                        "EXE"
#      define EXT_EXT2                        "EXT"
#      define html_EXT                        ".html"
#      define html_EXT2                       "html"
#      define KB_EXT                          ".kb"
#      define Keyboard_EXT                    ".keyboard"
#      define OLD_EXT2                        "OLD"
#      define PIV_EXT2                        "PIV"
#      define PRS_EXT                         ".PRS"
#      define PRS_EXT2                        "PRS"
#      define Ps_EXT2                         "ps"
#      define REF_EXT2                        "REF"
#      define SAV_EXT2                        "SAV"
#      define STR_EXT                         ".STR"
#      define STR_EXT2                        "STR"
#      define Tmp_EXT2                        "Tmp"
#      define TRA_EXT                         ".TRA"
#      define TRA_EXT2                        "TRA"
#      define X_EXT                           ".X"
#      define XML_EXT                         ".xml"
#      define XML_EXT2                        "XML"

#      define _RBinaryMODE_                   "rb"
#      define _RW_MODE_                       "rw"
#      define _WBinaryMODE_                   "wb" 
#      define _AppendBinaryMODE_              "wb+"
#      define _WriteMODE_                     "w" 
#      define _AppendMODE_                    "w+" 

#      define _USPaperFormat_                  "US"
#      define _A4PaperFormat_                  "A4"
#      define _A3PaperFormat_                  "A3"

#      ifdef _WINDOWS
/* #      define  WIN_DEF_TMPDIR           "c:\\temp" */
#      else  /* !_WINDOWS */
#      endif /* ! _WINDOWS */


#endif /* !_I18N_ */

#endif /* _UCS2_CONST */
